======
Canvas
======

Canvas commands are used to create, position, and modify canvas objects. The Canvas commands need only the abaqus module to be imported; no additional modules need to be imported.


Create layers in a viewport
---------------------------

Viewport
~~~~~~~~

.. autoclass:: abaqus.Canvas.Viewport.Viewport
    :members:
    :special-members: __init__

    .. autoclasstoc::


Classes
-------

Annotation features of Viewport
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

.. autoclass:: abaqus.Annotation.AnnotationViewport.AnnotationViewport
    :members:
    :special-members: __init__
    :noindex:

    .. autoclasstoc::

AttributeColorMap
~~~~~~~~~~~~~~~~~

.. autoclass:: abaqus.Canvas.AttributeColorMap.AttributeColorMap
    :members:
    :special-members: __init__

    .. autoclasstoc::

Canvas
~~~~~~

.. autoclass:: abaqus.Canvas.Canvas.Canvas
    :members:
    :special-members: __init__

Displayable
~~~~~~~~~~~

.. autoclass:: abaqus.Canvas.Displayable.Displayable
    :members:
    :special-members: __init__

DrawingArea
~~~~~~~~~~~

.. autoclass:: abaqus.Canvas.DrawingArea.DrawingArea
    :members:
    :special-members: __init__

    .. autoclasstoc::

Highlight
~~~~~~~~~

.. automodule:: abaqus.Canvas.Highlight
    :members:
    :special-members: __init__

ImageOptions
~~~~~~~~~~~~

.. autoclass:: abaqus.Canvas.ImageOptions.ImageOptions
    :members:
    :special-members: __init__

    .. autoclasstoc::

Layer
~~~~~

.. autoclass:: abaqus.Canvas.Layer.Layer
    :members:
    :special-members: __init__

    .. autoclasstoc::

MovieOptions
~~~~~~~~~~~~

.. autoclass:: abaqus.Canvas.MovieOptions.MovieOptions
    :members:
    :special-members: __init__

    .. autoclasstoc::

ViewportBase
~~~~~~~~~~~~

.. autoclass:: abaqus.Canvas.ViewportBase.ViewportBase
    :members:
    :special-members: __init__